@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #ifndef AUTOGAIN_UI_HPP
 #define AUTOGAIN_UI_HPP
 
@@ -38,7 +57,7 @@ class AutoGainUi : public Gtk::Grid, public PluginUiBase {
 
   Gtk::ToggleButton *detect_silence = nullptr, *use_geometric_mean = nullptr;
 
-  Gtk::Grid* weights_grid = nullptr;
+  Gtk::Grid *weight_m_grid = nullptr, *weight_s_grid = nullptr, *weight_i_grid = nullptr;
 };
 
 #endif
