@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #ifndef PIPELINE_COMMON_HPP
 #define PIPELINE_COMMON_HPP
 
@@ -14,8 +33,8 @@ void update_effects_order(gpointer user_data) {
 
   gst_element_unlink(l->identity_in, l->plugins[l->plugins_order_old[0]]);
 
-  for (long unsigned int n = 1; n < l->plugins_order_old.size(); n++) {
-    gst_element_unlink(l->plugins[l->plugins_order_old[n - 1]], l->plugins[l->plugins_order_old[n]]);
+  for (unsigned long int n = 1U; n < l->plugins_order_old.size(); n++) {
+    gst_element_unlink(l->plugins[l->plugins_order_old[n - 1U]], l->plugins[l->plugins_order_old[n]]);
   }
 
   gst_element_unlink(l->plugins[l->plugins_order_old.back()], l->identity_out);
@@ -28,8 +47,8 @@ void update_effects_order(gpointer user_data) {
     util::debug(l->log_tag + "failed to link identity_in to " + l->plugins_order[0]);
   }
 
-  for (long unsigned int n = 1; n < l->plugins_order.size(); n++) {
-    auto p1_name = l->plugins_order[n - 1];
+  for (unsigned long int n = 1U; n < l->plugins_order.size(); n++) {
+    auto p1_name = l->plugins_order[n - 1U];
     auto p2_name = l->plugins_order[n];
 
     if (gst_element_link(l->plugins[p1_name], l->plugins[p2_name])) {
