@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #ifndef PLUGIN_UI_BASE_HPP
 #define PLUGIN_UI_BASE_HPP
 
@@ -8,8 +27,10 @@
 #include <gtkmm/button.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/comboboxtext.h>
+#include <gtkmm/dialog.h>
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/filechoosernative.h>
+#include <gtkmm/frame.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/label.h>
 #include <gtkmm/levelbar.h>
@@ -22,10 +43,10 @@
 #include <gtkmm/stackswitcher.h>
 #include <gtkmm/switch.h>
 #include <gtkmm/togglebutton.h>
+#include <gtkmm/window.h>
 #include <array>
 #include <boost/property_tree/json_parser.hpp>
 #include <boost/property_tree/ptree.hpp>
-#include "preset_type.hpp"
 #include "util.hpp"
 
 class PluginUiBase {
@@ -39,10 +60,6 @@ class PluginUiBase {
 
   std::string name;
 
-  // preset_type to let the UI know which pipeline it belongs to
-  // initialized to "output"; to be changed to "input" for soe_ui properties
-  PresetType preset_type = PresetType::output;
-
   Gtk::Box* listbox_control = nullptr;
   Gtk::Button *plugin_up = nullptr, *plugin_down = nullptr;
 
@@ -50,7 +67,10 @@ class PluginUiBase {
   void on_new_output_level(const std::array<double, 2>& peak);
   void on_new_input_level_db(const std::array<double, 2>& peak);
   void on_new_output_level_db(const std::array<double, 2>& peak);
-  static auto level_to_str(const double& value, const int& places) -> std::string;
+
+  auto level_to_localized_string(const double& value, const int& places) -> std::string;
+  auto level_to_localized_string(const float& value, const int& places) -> std::string;
+  auto string_to_float(const std::string& value) -> float;
 
   // reset plugin method
   virtual void reset() = 0;
@@ -75,56 +95,22 @@ class PluginUiBase {
     object = Glib::RefPtr<Gtk::Adjustment>::cast_dynamic(builder->get_object(name));
   }
 
-  // reimplemented templates from plugin_preset_base without passing boost ptree
-  // using an empty root will rely on default value
   template <typename T>
-  auto get_default(const Glib::RefPtr<Gio::Settings>& settings, const std::string& key) -> T {
-    Glib::Variant<T> value;
+  auto level_to_localized_string_showpos(const T& value, const int& places) -> std::string {
+    std::ostringstream msg;
 
-    settings->get_default_value(key, value);
+    msg.imbue(global_locale);
+    msg.precision(places);
 
-    return value.get();
-  }
+    msg << ((value > 0.0) ? "+" : "") << std::fixed << value;
 
-  template <typename T>
-  void update_default_key(const Glib::RefPtr<Gio::Settings>& settings,
-                          const std::string& key,
-                          const std::string& json_key) {
-    boost::property_tree::ptree root;
-    Glib::Variant<T> aux;
-
-    settings->get_value(key, aux);
-
-    T current_value = aux.get();
-
-    T new_value = root.get<T>(json_key, get_default<T>(settings, key));
-
-    if (is_different(current_value, new_value)) {
-      auto v = Glib::Variant<T>::create(new_value);
-
-      settings->set_value(key, v);
-    }
-  }
-
-  void update_default_string_key(const Glib::RefPtr<Gio::Settings>& settings,
-                                 const std::string& key,
-                                 const std::string& json_key) {
-    boost::property_tree::ptree root;
-    std::string current_value = settings->get_string(key);
-
-    std::string new_value = root.get<std::string>(json_key, get_default<std::string>(settings, key));
-
-    if (current_value != new_value) {
-      settings->set_string(key, new_value);
-    }
-  }
-
-  template <typename T>
-  auto is_different(const T& a, const T& b) -> bool {
-    return a != b;
+    return msg.str();
   }
 
  private:
+  std::locale global_locale;
+  std::locale c_locale = std::locale();
+
   template <typename T1, typename T2, typename T3, typename T4>
   void update_level(const T1& w_left,
                     const T2& w_left_label,
@@ -136,19 +122,19 @@ class PluginUiBase {
     auto left_db = util::linear_to_db(left);
     auto right_db = util::linear_to_db(right);
 
-    if (left_db >= -99.0f) {
+    if (left_db >= -99.0) {
       w_left->set_value(left);
-      w_left_label->set_text(level_to_str(left_db, 0));
+      w_left_label->set_text(level_to_localized_string(left_db, 0));
     } else {
-      w_left->set_value(0);
+      w_left->set_value(0.0);
       w_left_label->set_text("-99");
     }
 
-    if (right_db >= -99.0f) {
+    if (right_db >= -99.0) {
       w_right->set_value(right);
-      w_right_label->set_text(level_to_str(right_db, 0));
+      w_right_label->set_text(level_to_localized_string(right_db, 0));
     } else {
-      w_right->set_value(0);
+      w_right->set_value(0.0);
       w_right_label->set_text("-99");
     }
   }
@@ -165,32 +151,32 @@ class PluginUiBase {
     if (left >= -99.0) {
       auto db_value = util::db_to_linear(left);
 
-      if (db_value < 0.0f) {
-        db_value = 0;
-      } else if (db_value > 1.0f) {
-        db_value = 1;
+      if (db_value < 0.0) {
+        db_value = 0.0;
+      } else if (db_value > 1.0) {
+        db_value = 1.0;
       }
 
       w_left->set_value(db_value);
-      w_left_label->set_text(level_to_str(left, 0));
+      w_left_label->set_text(level_to_localized_string(left, 0));
     } else {
-      w_left->set_value(0);
+      w_left->set_value(0.0);
       w_left_label->set_text("-99");
     }
 
     if (right >= -99.0) {
       auto db_value = util::db_to_linear(right);
 
-      if (db_value < 0.0f) {
-        db_value = 0;
-      } else if (db_value > 1.0f) {
-        db_value = 1;
+      if (db_value < 0.0) {
+        db_value = 0.0;
+      } else if (db_value > 1.0) {
+        db_value = 1.0;
       }
 
       w_right->set_value(db_value);
-      w_right_label->set_text(level_to_str(right, 0));
+      w_right_label->set_text(level_to_localized_string(right, 0));
     } else {
-      w_right->set_value(0);
+      w_right->set_value(0.0);
       w_right_label->set_text("-99");
     }
   }
