@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #ifndef PULSE_MANAGER_HPP
 #define PULSE_MANAGER_HPP
 
@@ -61,8 +80,9 @@ struct AppInfo {
   uint index;
   std::string name;
   std::string icon_name;
+  std::string media_name;
   uint8_t channels;
-  float volume;
+  double volume;
   uint rate;
   std::string resampler;
   std::string format;
@@ -95,8 +115,8 @@ class PulseManager {
   auto get_sink_info(const std::string& name) -> std::shared_ptr<mySinkInfo>;
   auto get_source_info(const std::string& name) -> std::shared_ptr<mySourceInfo>;
 
-  std::vector<std::string> blacklist_in;   // for input effects
-  std::vector<std::string> blacklist_out;  // for output effects
+  std::vector<std::string> blocklist_in;   // for input effects
+  std::vector<std::string> blocklist_out;  // for output effects
 
   void find_sink_inputs();
   void find_source_outputs();
@@ -114,6 +134,7 @@ class PulseManager {
   void update_server_info(const pa_server_info* info);
   void get_modules_info();
   void get_clients_info();
+  void set_sink_volume_by_name(const std::string& name, uint8_t channels, uint value);
 
   sigc::signal<void, std::shared_ptr<mySourceInfo>> source_added;
   sigc::signal<void, std::shared_ptr<mySourceInfo>> source_changed;
@@ -141,15 +162,15 @@ class PulseManager {
   pa_mainloop_api* main_loop_api = nullptr;
   pa_context* context = nullptr;
 
-  std::array<std::string, 7> blacklist_apps = {
+  std::array<std::string, 7> blocklist_apps = {
       "PulseEffectsWebrtcProbe", "gsd-media-keys", "GNOME Shell", "libcanberra", "Screenshot", "speech-dispatcher"};
 
-  std::array<std::string, 4> blacklist_media_name = {"pulsesink probe", "bell-window-system", "audio-volume-change",
+  std::array<std::string, 4> blocklist_media_name = {"pulsesink probe", "bell-window-system", "audio-volume-change",
                                                      "screen-capture"};
 
-  std::array<std::string, 1> blacklist_media_role = {"event"};
+  std::array<std::string, 1> blocklist_media_role = {"event"};
 
-  std::array<std::string, 4> blacklist_app_id = {"com.github.wwmm.pulseeffects.sinkinputs",
+  std::array<std::string, 4> blocklist_app_id = {"com.github.wwmm.pulseeffects.sinkinputs",
                                                  "com.github.wwmm.pulseeffects.sourceoutputs",
                                                  "org.PulseAudio.pavucontrol", "org.gnome.VolumeControl"};
 
@@ -210,7 +231,7 @@ class PulseManager {
       app_name = prop;
 
       forbidden_app =
-          std::find(std::begin(blacklist_apps), std::end(blacklist_apps), app_name) != std::end(blacklist_apps);
+          std::find(std::begin(blocklist_apps), std::end(blocklist_apps), app_name) != std::end(blocklist_apps);
 
       if (forbidden_app) {
         return nullptr;
@@ -226,8 +247,8 @@ class PulseManager {
         app_name = media_name;
       }
 
-      forbidden_app = std::find(std::begin(blacklist_media_name), std::end(blacklist_media_name), media_name) !=
-                      std::end(blacklist_media_name);
+      forbidden_app = std::find(std::begin(blocklist_media_name), std::end(blocklist_media_name), media_name) !=
+                      std::end(blocklist_media_name);
 
       if (forbidden_app) {
         return nullptr;
@@ -239,8 +260,8 @@ class PulseManager {
     if (prop != nullptr) {
       media_role = prop;
 
-      forbidden_app = std::find(std::begin(blacklist_media_role), std::end(blacklist_media_role), media_role) !=
-                      std::end(blacklist_media_role);
+      forbidden_app = std::find(std::begin(blocklist_media_role), std::end(blocklist_media_role), media_role) !=
+                      std::end(blocklist_media_role);
 
       if (forbidden_app) {
         return nullptr;
@@ -253,7 +274,7 @@ class PulseManager {
       app_id = prop;
 
       forbidden_app =
-          std::find(std::begin(blacklist_app_id), std::end(blacklist_app_id), app_id) != std::end(blacklist_app_id);
+          std::find(std::begin(blocklist_app_id), std::end(blocklist_app_id), app_id) != std::end(blocklist_app_id);
 
       if (forbidden_app) {
         return nullptr;
@@ -287,7 +308,7 @@ class PulseManager {
     ai->visible = true;
 
     // linear volume
-    ai->volume = 100 * pa_cvolume_max(&info->volume) / PA_VOLUME_NORM;
+    ai->volume = 100.0 * (static_cast<double>(pa_cvolume_max(&info->volume)) / PA_VOLUME_NORM);
 
     if (info->resample_method) {
       ai->resampler = info->resample_method;
@@ -299,7 +320,7 @@ class PulseManager {
 
     ai->index = info->index;
     ai->name = app_name;
-    ai->app_type = "";
+    ai->media_name = media_name;
     ai->icon_name = icon_name;
     ai->channels = info->volume.channels;
     ai->rate = info->sample_spec.rate;
