@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "autogain.hpp"
 #include <glibmm/main.h>
 #include "util.hpp"
@@ -5,7 +24,7 @@
 namespace {
 
 void on_m_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "m", &v, nullptr);
 
@@ -13,7 +32,7 @@ void on_m_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 }
 
 void on_s_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "s", &v, nullptr);
 
@@ -21,7 +40,7 @@ void on_s_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 }
 
 void on_i_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "i", &v, nullptr);
 
@@ -29,7 +48,7 @@ void on_i_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 }
 
 void on_r_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "r", &v, nullptr);
 
@@ -37,7 +56,7 @@ void on_r_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 }
 
 void on_l_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "l", &v, nullptr);
 
@@ -45,7 +64,7 @@ void on_l_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 }
 
 void on_lra_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "lra", &v, nullptr);
 
@@ -53,7 +72,7 @@ void on_lra_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
 }
 
 void on_g_changed(GObject* gobject, GParamSpec* pspec, AutoGain* a) {
-  float v;
+  float v = 0.0F;
 
   g_object_get(a->autogain, "g", &v, nullptr);
 
