@@ -1,9 +1,34 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "calibration_ui.hpp"
-#include <glibmm/i18n.h>
-#include "util.hpp"
 
 CalibrationUi::CalibrationUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
     : Gtk::Window(cobject) {
+  // set locale (workaround for #849)
+
+  try {
+    global_locale = std::locale("");
+  } catch (const std::exception& e) {
+    global_locale = std::locale();
+  }
+
   // loading glade widgets
 
   builder->get_widget("stack", stack);
@@ -76,16 +101,16 @@ auto CalibrationUi::on_spectrum_draw(const Cairo::RefPtr<Cairo::Context>& ctx) -
     auto width = allocation.get_width();
     auto height = allocation.get_height();
     auto n_bars = spectrum_mag.size();
-    auto x = util::linspace(0, width, n_bars);
+    auto x = util::linspace(0.0F, static_cast<float>(width), n_bars);
 
-    for (uint n = 0; n < n_bars - 1; n++) {
+    for (uint n = 0U; n < n_bars - 1U; n++) {
       auto bar_height = spectrum_mag[n] * height;
 
       ctx->move_to(x[n], height - bar_height);
 
-      bar_height = spectrum_mag[n + 1] * height;
+      bar_height = spectrum_mag[n + 1U] * height;
 
-      ctx->line_to(x[n + 1], height - bar_height);
+      ctx->line_to(x[n + 1U], height - bar_height);
     }
 
     auto color = Gdk::RGBA();
@@ -101,7 +126,9 @@ auto CalibrationUi::on_spectrum_draw(const Cairo::RefPtr<Cairo::Context>& ctx) -
     if (mouse_inside) {
       std::ostringstream msg;
 
+      msg.imbue(global_locale);
       msg.precision(0);
+
       msg << std::fixed << mouse_freq << " Hz, ";
       msg << std::fixed << mouse_intensity << " dB";
 
@@ -109,8 +136,8 @@ auto CalibrationUi::on_spectrum_draw(const Cairo::RefPtr<Cairo::Context>& ctx) -
       font.set_family("Monospace");
       font.set_weight(Pango::WEIGHT_BOLD);
 
-      int text_width;
-      int text_height;
+      int text_width = 0;
+      int text_height = 0;
       auto layout = create_pango_layout(msg.str());
       layout->set_font_description(font);
       layout->get_pixel_size(text_width, text_height);
