@@ -1,13 +1,23 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "convolver_ui.hpp"
-#include <glibmm.h>
-#include <glibmm/i18n.h>
-#include <gst/fft/gstfftf32.h>
-#include <gtkmm/filechoosernative.h>
-#include <boost/math/interpolators/cardinal_cubic_b_spline.hpp>
-#include <sndfile.hh>
-#include "gtkmm/dialog.h"
-// #include "gtkmm/window.h"
-#include "sigc++/functors/ptr_fun.h"
 
 ConvolverUi::ConvolverUi(BaseObjectType* cobject,
                          const Glib::RefPtr<Gtk::Builder>& builder,
@@ -131,23 +141,15 @@ ConvolverUi::~ConvolverUi() {
 }
 
 void ConvolverUi::reset() {
-  try {
-    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+  settings->reset("state");
 
-    update_default_key<bool>(settings, "state", section + ".convolver.state");
+  settings->reset("input-gain");
 
-    update_default_key<double>(settings, "input-gain", section + ".convolver.input-gain");
+  settings->reset("output-gain");
 
-    update_default_key<double>(settings, "output-gain", section + ".convolver.output-gain");
+  settings->reset("kernel-path");
 
-    update_default_string_key(settings, "kernel-path", section + ".convolver.kernel-path");
-
-    update_default_key<int>(settings, "ir-width", section + ".convolver.ir-width");
-
-    util::debug(name + " plugin: successfully reset");
-  } catch (std::exception& e) {
-    util::debug(name + " plugin: an error occurred during reset process");
-  }
+  settings->reset("ir-width");
 }
 
 auto ConvolverUi::get_irs_names() -> std::vector<std::string> {
@@ -335,14 +337,14 @@ void ConvolverUi::get_irs_info() {
   // build plot time axis
 
   float dt = 1.0F / rate;
-  float duration = (static_cast<float>(frames_in) - 1) * dt;
+  float duration = (static_cast<float>(frames_in) - 1.0F) * dt;
   uint max_points = (frames_in > max_plot_points) ? max_plot_points : frames_in;
   float plot_dt = duration / max_points;
 
   time_axis.resize(max_points);
   time_axis.shrink_to_fit();
 
-  for (uint n = 0; n < max_points; n++) {
+  for (uint n = 0U; n < max_points; n++) {
     time_axis[n] = n * plot_dt;
   }
 
@@ -355,20 +357,20 @@ void ConvolverUi::get_irs_info() {
 
   // ensure that the fft can be computed
 
-  if (left_mag.size() % 2 != 0) {
-    left_mag.emplace_back(0);
+  if (left_mag.size() % 2U != 0U) {
+    left_mag.emplace_back(0.0F);
   }
 
-  if (right_mag.size() % 2 != 0) {
-    right_mag.emplace_back(0);
+  if (right_mag.size() % 2U != 0U) {
+    right_mag.emplace_back(0.0F);
   }
 
   left_mag.shrink_to_fit();
   right_mag.shrink_to_fit();
 
-  for (uint n = 0; n < frames_in; n++) {
-    left_mag[n] = kernel[2 * n];
-    right_mag[n] = kernel[2 * n + 1];
+  for (uint n = 0U; n < frames_in; n++) {
+    left_mag[n] = kernel[2U * n];
+    right_mag[n] = kernel[2U * n + 1U];
   }
 
   get_irs_spectrum(rate);
@@ -388,7 +390,7 @@ void ConvolverUi::get_irs_info() {
     left_mag.shrink_to_fit();
     right_mag.shrink_to_fit();
 
-    for (uint n = 0; n < max_points; n++) {
+    for (uint n = 0U; n < max_points; n++) {
       left_mag[n] = spline_L(time_axis[n]);
       right_mag[n] = spline_R(time_axis[n]);
     }
@@ -405,7 +407,7 @@ void ConvolverUi::get_irs_info() {
 
   // rescaling between 0 and 1
 
-  for (uint n = 0; n < max_points; n++) {
+  for (uint n = 0U; n < max_points; n++) {
     left_mag[n] = (left_mag[n] - min_left) / (max_left - min_left);
     right_mag[n] = (right_mag[n] - min_right) / (max_right - min_right);
   }
@@ -416,12 +418,7 @@ void ConvolverUi::get_irs_info() {
     label_sampling_rate->set_text(std::to_string(rate) + " Hz");
     label_samples->set_text(std::to_string(frames_in));
 
-    std::ostringstream msg;
-
-    msg.precision(3);
-    msg << duration << " s";
-
-    label_duration->set_text(msg.str());
+    label_duration->set_text(level_to_localized_string(duration, 3) + " s");
 
     auto fpath = boost::filesystem::path{path};
 
@@ -433,11 +430,11 @@ void ConvolverUi::get_irs_info() {
 }
 
 void ConvolverUi::get_irs_spectrum(const int& rate) {
-  int nfft = left_mag.size();  // right_mag.size() should have the same value
+  uint nfft = left_mag.size();  // right_mag.size() should have the same value
 
   GstFFTF32* fft_ctx = gst_fft_f32_new(nfft, 0);
-  auto* freqdata_l = g_new0(GstFFTF32Complex, nfft / 2 + 1);
-  auto* freqdata_r = g_new0(GstFFTF32Complex, nfft / 2 + 1);
+  auto* freqdata_l = g_new0(GstFFTF32Complex, nfft / 2U + 1U);
+  auto* freqdata_r = g_new0(GstFFTF32Complex, nfft / 2U + 1U);
 
   std::vector<float> tmp_l;
   std::vector<float> tmp_r;
@@ -454,12 +451,12 @@ void ConvolverUi::get_irs_spectrum(const int& rate) {
   gst_fft_f32_fft(fft_ctx, tmp_l.data(), freqdata_l);
   gst_fft_f32_fft(fft_ctx, tmp_r.data(), freqdata_r);
 
-  left_spectrum.resize(nfft / 2 + 1);
-  right_spectrum.resize(nfft / 2 + 1);
+  left_spectrum.resize(nfft / 2U + 1U);
+  right_spectrum.resize(nfft / 2U + 1U);
 
-  for (int i = 0; i < nfft / 2 + 1; i++) {
-    float v_l = 0.0;
-    float v_r = 0.0;
+  for (uint i = 0U; i < nfft / 2U + 1U; i++) {
+    float v_l = 0.0F;
+    float v_r = 0.0F;
 
     // left
     v_l = freqdata_l[i].r * freqdata_l[i].r;
@@ -476,9 +473,9 @@ void ConvolverUi::get_irs_spectrum(const int& rate) {
     right_spectrum[i] = v_r;
   }
 
-  uint max_points = std::min((uint)left_spectrum.size(), max_plot_points);
+  uint max_points = std::min(static_cast<uint>(left_spectrum.size()), max_plot_points);
 
-  fft_min_freq = 1;
+  fft_min_freq = 1.0F;
   fft_max_freq = 0.5F * static_cast<float>(rate);
 
   freq_axis = util::logspace(log10(fft_min_freq), log10(fft_max_freq), max_points);
@@ -502,7 +499,7 @@ void ConvolverUi::get_irs_spectrum(const int& rate) {
     left_spectrum.shrink_to_fit();
     right_spectrum.shrink_to_fit();
 
-    for (uint n = 0; n < max_points; n++) {
+    for (uint n = 0U; n < max_points; n++) {
       left_spectrum[n] = spline_L(freq_axis[n]);
       right_spectrum[n] = spline_R(freq_axis[n]);
     }
@@ -519,7 +516,7 @@ void ConvolverUi::get_irs_spectrum(const int& rate) {
 
   // rescaling between 0 and 1
 
-  for (unsigned int n = 0; n < left_spectrum.size(); n++) {
+  for (unsigned int n = 0U; n < left_spectrum.size(); n++) {
     left_spectrum[n] = (left_spectrum[n] - fft_min_left) / (fft_max_left - fft_min_left);
     right_spectrum[n] = (right_spectrum[n] - fft_min_right) / (fft_max_right - fft_min_right);
   }
@@ -534,21 +531,21 @@ void ConvolverUi::draw_channel(Gtk::DrawingArea* da,
                                const std::vector<float>& magnitudes) {
   auto n_bars = magnitudes.size();
 
-  if (n_bars > 0) {
+  if (n_bars > 0U) {
     auto allocation = da->get_allocation();
     auto width = allocation.get_width();
     auto height = allocation.get_height();
     auto n_bars = magnitudes.size();
-    auto x = util::linspace(0, width, n_bars);
+    auto x = util::linspace(0.0F, static_cast<float>(width), n_bars);
 
-    for (uint n = 0; n < n_bars - 1; n++) {
+    for (uint n = 0U; n < n_bars - 1U; n++) {
       auto bar_height = magnitudes[n] * height;
 
       ctx->move_to(x[n], height - bar_height);
 
-      bar_height = magnitudes[n + 1] * height;
+      bar_height = magnitudes[n + 1U] * height;
 
-      ctx->line_to(x[n + 1], height - bar_height);
+      ctx->line_to(x[n + 1U], height - bar_height);
     }
 
     if (spectrum_settings->get_boolean("use-custom-color")) {
@@ -570,22 +567,19 @@ void ConvolverUi::draw_channel(Gtk::DrawingArea* da,
     ctx->stroke();
 
     if (mouse_inside) {
-      std::ostringstream msg;
+      std::string msg;
 
       if (show_fft_spectrum) {
-        msg.precision(0);
-        msg << std::fixed << mouse_freq << " Hz, ";
+        msg.append(level_to_localized_string(mouse_freq, 0) + " Hz, ");
+        msg.append(level_to_localized_string(mouse_intensity, 3));
       } else {
-        msg.precision(3);
-        msg << std::fixed << mouse_time << " s, ";
+        msg.append(level_to_localized_string(mouse_time, 3) + " s, ");
+        msg.append(level_to_localized_string_showpos(mouse_intensity, 3));
       }
 
-      msg.precision(3);
-      msg << std::fixed << mouse_intensity;
-
       int text_width = 0;
       int text_height = 0;
-      auto layout = create_pango_layout(msg.str());
+      auto layout = create_pango_layout(msg);
       layout->set_font_description(font);
       layout->get_pixel_size(text_width, text_height);
 
