@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "crossfeed_ui.hpp"
 
 CrossfeedUi::CrossfeedUi(BaseObjectType* cobject,
@@ -36,32 +55,24 @@ CrossfeedUi::~CrossfeedUi() {
 }
 
 void CrossfeedUi::reset() {
-  try {
-    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+  settings->reset("fcut");
 
-    update_default_key<int>(settings, "fcut", section + ".crossfeed.fcut");
-
-    update_default_key<double>(settings, "feed", section + ".crossfeed.feed");
-
-    util::debug(name + " plugin: successfully reset");
-  } catch (std::exception& e) {
-    util::debug(name + " plugin: an error occurred during reset process");
-  }
+  settings->reset("feed");
 }
 
 void CrossfeedUi::init_presets_buttons() {
   preset_cmoy->signal_clicked().connect([=]() {
-    fcut->set_value(700);
-    feed->set_value(6);
+    fcut->set_value(700.0);
+    feed->set_value(6.0);
   });
 
   preset_default->signal_clicked().connect([=]() {
-    fcut->set_value(700);
+    fcut->set_value(700.0);
     feed->set_value(4.5);
   });
 
   preset_jmeier->signal_clicked().connect([=]() {
-    fcut->set_value(650);
-    feed->set_value(9);
+    fcut->set_value(650.0);
+    feed->set_value(9.0);
   });
 }
