@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "equalizer_preset.hpp"
 #include "util.hpp"
 
@@ -24,7 +43,7 @@ void EqualizerPreset::save(boost::property_tree::ptree& root,
 
   root.put(section + ".equalizer.mode", settings->get_string("mode"));
 
-  int nbands = settings->get_int("num-bands");
+  const auto& nbands = settings->get_int("num-bands");
 
   root.put(section + ".equalizer.num-bands", nbands);
 
@@ -87,7 +106,7 @@ void EqualizerPreset::load(const boost::property_tree::ptree& root,
 
   update_key<double>(root, settings, "output-gain", section + ".equalizer.output-gain");
 
-  int nbands = settings->get_int("num-bands");
+  const auto& nbands = settings->get_int("num-bands");
 
   update_key<bool>(root, settings, "split-channels", section + ".equalizer.split-channels");
 
@@ -132,17 +151,23 @@ void EqualizerPreset::load_channel(const boost::property_tree::ptree& root,
 }
 
 void EqualizerPreset::write(PresetType preset_type, boost::property_tree::ptree& root) {
-  if (preset_type == PresetType::output) {
-    save(root, "output", output_settings);
-  } else {
-    save(root, "input", input_settings);
+  switch (preset_type) {
+    case PresetType::output:
+      save(root, "output", output_settings);
+      break;
+    case PresetType::input:
+      save(root, "input", input_settings);
+      break;
   }
 }
 
 void EqualizerPreset::read(PresetType preset_type, const boost::property_tree::ptree& root) {
-  if (preset_type == PresetType::output) {
-    load(root, "output", output_settings);
-  } else {
-    load(root, "input", input_settings);
+  switch (preset_type) {
+    case PresetType::output:
+      load(root, "output", output_settings);
+      break;
+    case PresetType::input:
+      load(root, "input", input_settings);
+      break;
   }
 }
