@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "exciter_ui.hpp"
 
 ExciterUi::ExciterUi(BaseObjectType* cobject,
@@ -49,35 +68,27 @@ ExciterUi::~ExciterUi() {
 }
 
 void ExciterUi::reset() {
-  try {
-    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+  settings->reset("input-gain");
 
-    update_default_key<double>(settings, "input-gain", section + ".exciter.input-gain");
+  settings->reset("output-gain");
 
-    update_default_key<double>(settings, "output-gain", section + ".exciter.output-gain");
+  settings->reset("amount");
 
-    update_default_key<double>(settings, "amount", section + ".exciter.amount");
+  settings->reset("harmonics");
 
-    update_default_key<double>(settings, "harmonics", section + ".exciter.harmonics");
+  settings->reset("scope");
 
-    update_default_key<double>(settings, "scope", section + ".exciter.scope");
+  settings->reset("ceil");
 
-    update_default_key<double>(settings, "ceil", section + ".exciter.ceil");
+  settings->reset("blend");
 
-    update_default_key<double>(settings, "blend", section + ".exciter.blend");
+  settings->reset("ceil-active");
 
-    update_default_key<bool>(settings, "ceil-active", section + ".exciter.ceil-active");
-
-    update_default_key<bool>(settings, "listen", section + ".exciter.listen");
-
-    util::debug(name + " plugin: successfully reset");
-  } catch (std::exception& e) {
-    util::debug(name + " plugin: an error occurred during reset process");
-  }
+  settings->reset("listen");
 }
 
 void ExciterUi::on_new_harmonics_level(double value) {
   harmonics_levelbar->set_value(value);
 
-  harmonics_levelbar_label->set_text(level_to_str(util::linear_to_db(static_cast<float>(value)), 0));
+  harmonics_levelbar_label->set_text(level_to_localized_string(util::linear_to_db(value), 0));
 }
