@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "loudness.hpp"
 #include <glibmm/main.h>
 #include "util.hpp"
@@ -25,7 +44,6 @@ Loudness::Loudness(const std::string& tag, const std::string& schema, const std:
     gst_object_unref(GST_OBJECT(pad_src));
 
     g_object_set(loudness, "enabled", 1, nullptr);
-    g_object_set(loudness, "refer", 0, nullptr);
     g_object_set(loudness, "hclip", 0, nullptr);
 
     bind_to_gsettings();
@@ -55,6 +73,4 @@ void Loudness::bind_to_gsettings() {
   g_settings_bind(settings, "fft", loudness, "fft", G_SETTINGS_BIND_DEFAULT);
 
   g_settings_bind(settings, "std", loudness, "std", G_SETTINGS_BIND_DEFAULT);
-
-  g_settings_bind(settings, "reference-signal", loudness, "refer", G_SETTINGS_BIND_DEFAULT);
 }
