@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "pitch_ui.hpp"
 
 PitchUi::PitchUi(BaseObjectType* cobject,
@@ -43,27 +62,19 @@ PitchUi::~PitchUi() {
 }
 
 void PitchUi::reset() {
-  try {
-    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+  settings->reset("input-gain");
 
-    update_default_key<double>(settings, "input-gain", section + ".pitch.input-gain");
+  settings->reset("output-gain");
 
-    update_default_key<double>(settings, "output-gain", section + ".pitch.output-gain");
+  settings->reset("cents");
 
-    update_default_key<double>(settings, "cents", section + ".pitch.cents");
+  settings->reset("semitones");
 
-    update_default_key<int>(settings, "semitones", section + ".pitch.semitones");
+  settings->reset("octaves");
 
-    update_default_key<int>(settings, "octaves", section + ".pitch.octaves");
+  settings->reset("crispness");
 
-    update_default_key<int>(settings, "crispness", section + ".pitch.crispness");
+  settings->reset("formant-preserving");
 
-    update_default_key<bool>(settings, "formant-preserving", section + ".pitch.formant-preserving");
-
-    update_default_key<bool>(settings, "faster", section + ".pitch.faster");
-
-    util::debug(name + " plugin: successfully reset");
-  } catch (std::exception& e) {
-    util::debug(name + " plugin: an error occurred during reset process");
-  }
+  settings->reset("faster");
 }
