@@ -1,9 +1,38 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "plugin_ui_base.hpp"
 
 PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder,
                            const std::string& schema,
                            const std::string& schema_path)
     : settings(Gio::Settings::create(schema, schema_path)) {
+  // set locale (workaround for #849)
+
+  try {
+    global_locale = std::locale("");
+  } catch (const std::exception& e) {
+    global_locale = std::locale();
+  }
+
+  // get widgets
+
   builder->get_widget("enable", enable);
   builder->get_widget("listbox_control", listbox_control);
   builder->get_widget("controls", controls);
@@ -42,15 +71,40 @@ PluginUiBase::~PluginUiBase() {
   settings->set_boolean("post-messages", false);
 }
 
-auto PluginUiBase::level_to_str(const double& value, const int& places) -> std::string {
+auto PluginUiBase::level_to_localized_string(const double& value, const int& places) -> std::string {
   std::ostringstream msg;
 
+  msg.imbue(global_locale);
   msg.precision(places);
+
   msg << std::fixed << value;
 
   return msg.str();
 }
 
+auto PluginUiBase::level_to_localized_string(const float& value, const int& places) -> std::string {
+  std::ostringstream msg;
+
+  msg.imbue(global_locale);
+  msg.precision(places);
+
+  msg << std::fixed << value;
+
+  return msg.str();
+}
+
+auto PluginUiBase::string_to_float(const std::string& value) -> float {
+  std::stringstream ss;
+  ss.imbue(c_locale);
+
+  float fv = 0.0F;
+
+  ss << value;
+  ss >> fv;
+
+  return fv;
+}
+
 void PluginUiBase::on_new_input_level(const std::array<double, 2>& peak) {
   update_level(input_level_left, input_level_left_label, input_level_right, input_level_right_label, peak);
 }
