@@ -1,3 +1,22 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "pulse_settings_ui.hpp"
 #include <cstring>
 #include "util.hpp"
@@ -5,7 +24,7 @@
 namespace {
 
 auto blocksize_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "64") == 0) {
     g_value_set_int(value, 0);
@@ -27,33 +46,33 @@ auto blocksize_enum_to_int(GValue* value, GVariant* variant, gpointer user_data)
 }
 
 auto int_to_blocksize_enum(const GValue* value, const GVariantType* expected_type, gpointer user_data) -> GVariant* {
-  int v = g_value_get_int(value);
+  const auto v = g_value_get_int(value);
 
-  if (v == 0) {
-    return g_variant_new_string("64");
+  switch (v) {
+    case 0:
+      return g_variant_new_string("64");
+
+    case 1:
+      return g_variant_new_string("128");
+
+    case 2:
+      return g_variant_new_string("256");
+
+    case 3:
+      return g_variant_new_string("512");
+
+    case 4:
+      return g_variant_new_string("1024");
+
+    case 5:
+      return g_variant_new_string("2048");
+
+    case 6:
+      return g_variant_new_string("4096");
+
+    default:
+      return g_variant_new_string("512");
   }
-
-  if (v == 1) {
-    return g_variant_new_string("128");
-  }
-
-  if (v == 2) {
-    return g_variant_new_string("256");
-  }
-
-  if (v == 3) {
-    return g_variant_new_string("512");
-  }
-
-  if (v == 4) {
-    return g_variant_new_string("1024");
-  }
-
-  if (v == 5) {
-    return g_variant_new_string("2048");
-  }
-
-  return g_variant_new_string("4096");
 }
 
 }  // namespace
@@ -155,7 +174,7 @@ void PulseSettingsUi::on_sink_added(const std::shared_ptr<mySinkInfo>& info) {
   auto children = sink_list->children();
 
   for (const auto& c : children) {
-    uint i;
+    uint i = 0U;
     std::string name;
 
     c.get_value(0, i);
@@ -197,7 +216,7 @@ void PulseSettingsUi::on_sink_removed(uint idx) {
   auto children = sink_list->children();
 
   for (const auto& c : children) {
-    uint i;
+    uint i = 0U;
     std::string name;
 
     c.get_value(0, i);
@@ -222,7 +241,7 @@ void PulseSettingsUi::on_source_added(const std::shared_ptr<mySourceInfo>& info)
   auto children = source_list->children();
 
   for (const auto& c : children) {
-    uint i;
+    uint i = 0U;
     std::string name;
 
     c.get_value(0, i);
@@ -264,7 +283,7 @@ void PulseSettingsUi::on_source_removed(uint idx) {
   auto children = source_list->children();
 
   for (const auto& c : children) {
-    uint i;
+    uint i = 0U;
     std::string name;
 
     c.get_value(0, i);
@@ -319,7 +338,7 @@ void PulseSettingsUi::on_input_device_changed() {
   Gtk::TreeModel::Row row = *(input_device->get_active());
 
   if (row) {
-    uint index;
+    uint index = 0U;
     std::string name;
 
     row.get_value(0, index);
@@ -339,7 +358,7 @@ void PulseSettingsUi::on_output_device_changed() {
   Gtk::TreeModel::Row row = *(output_device->get_active());
 
   if (row) {
-    uint index;
+    uint index = 0U;
     std::string name;
 
     row.get_value(0, index);
