@@ -1,10 +1,29 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "reverb_ui.hpp"
 #include <cstring>
 
 namespace {
 
 auto room_size_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "Small") == 0) {
     g_value_set_int(value, 0);
@@ -24,29 +43,30 @@ auto room_size_enum_to_int(GValue* value, GVariant* variant, gpointer user_data)
 }
 
 auto int_to_room_size_enum(const GValue* value, const GVariantType* expected_type, gpointer user_data) -> GVariant* {
-  int v = g_value_get_int(value);
+  const auto v = g_value_get_int(value);
 
-  if (v == 0) {
-    return g_variant_new_string("Small");
+  switch (v) {
+    case 0:
+      return g_variant_new_string("Small");
+
+    case 1:
+      return g_variant_new_string("Medium");
+
+    case 2:
+      return g_variant_new_string("Large");
+
+    case 3:
+      return g_variant_new_string("Tunnel-like");
+
+    case 4:
+      return g_variant_new_string("Large/smooth");
+
+    case 5:
+      return g_variant_new_string("Experimental");
+
+    default:
+      return g_variant_new_string("Large");
   }
-
-  if (v == 1) {
-    return g_variant_new_string("Medium");
-  }
-
-  if (v == 2) {
-    return g_variant_new_string("Large");
-  }
-
-  if (v == 3) {
-    return g_variant_new_string("Tunnel-like");
-  }
-
-  if (v == 4) {
-    return g_variant_new_string("Large/smooth");
-  }
-
-  return g_variant_new_string("Experimental");
 }
 
 }  // namespace
@@ -111,35 +131,27 @@ ReverbUi::~ReverbUi() {
 }
 
 void ReverbUi::reset() {
-  try {
-    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+  settings->reset("input-gain");
 
-    update_default_key<double>(settings, "input-gain", section + ".reverb.input-gain");
+  settings->reset("output-gain");
 
-    update_default_key<double>(settings, "output-gain", section + ".reverb.output-gain");
+  settings->reset("room-size");
 
-    update_default_string_key(settings, "room-size", section + ".reverb.room-size");
+  settings->reset("decay-time");
 
-    update_default_key<double>(settings, "decay-time", section + ".reverb.decay-time");
+  settings->reset("hf-damp");
 
-    update_default_key<double>(settings, "hf-damp", section + ".reverb.hf-damp");
+  settings->reset("diffusion");
 
-    update_default_key<double>(settings, "diffusion", section + ".reverb.diffusion");
+  settings->reset("amount");
 
-    update_default_key<double>(settings, "amount", section + ".reverb.amount");
+  settings->reset("dry");
 
-    update_default_key<double>(settings, "dry", section + ".reverb.dry");
+  settings->reset("predelay");
 
-    update_default_key<double>(settings, "predelay", section + ".reverb.predelay");
+  settings->reset("bass-cut");
 
-    update_default_key<double>(settings, "bass-cut", section + ".reverb.bass-cut");
-
-    update_default_key<double>(settings, "treble-cut", section + ".reverb.treble-cut");
-
-    util::debug(name + " plugin: successfully reset");
-  } catch (std::exception& e) {
-    util::debug(name + " plugin: an error occurred during reset process");
-  }
+  settings->reset("treble-cut");
 }
 
 void ReverbUi::init_presets_buttons() {
@@ -149,10 +161,10 @@ void ReverbUi::init_presets_buttons() {
     room_size->set_active(4);
     diffusion->set_value(0.54);
     amount->set_value(util::linear_to_db(0.469761));
-    dry->set_value(util::linear_to_db(1));
-    predelay->set_value(25);
+    dry->set_value(util::linear_to_db(1.0));
+    predelay->set_value(25.0);
     bass_cut->set_value(257.65);
-    treble_cut->set_value(20000);
+    treble_cut->set_value(20000.0);
   });
 
   preset_empty_walls->signal_clicked().connect([=]() {
@@ -161,8 +173,8 @@ void ReverbUi::init_presets_buttons() {
     room_size->set_active(4);
     diffusion->set_value(0.17);
     amount->set_value(util::linear_to_db(0.198884));
-    dry->set_value(util::linear_to_db(1));
-    predelay->set_value(13);
+    dry->set_value(util::linear_to_db(1.0));
+    predelay->set_value(13.0);
     bass_cut->set_value(240.453);
     treble_cut->set_value(3303.47);
   });
@@ -173,7 +185,7 @@ void ReverbUi::init_presets_buttons() {
     room_size->set_active(4);
     diffusion->set_value(0.69);
     amount->set_value(util::linear_to_db(0.291183));
-    dry->set_value(util::linear_to_db(1));
+    dry->set_value(util::linear_to_db(1.0));
     predelay->set_value(6.5);
     bass_cut->set_value(514.079);
     treble_cut->set_value(4064.15);
@@ -181,7 +193,7 @@ void ReverbUi::init_presets_buttons() {
 
   preset_large_empty_hall->signal_clicked().connect([=]() {
     decay_time->set_value(2.00689);
-    hf_damp->set_value(20000);
+    hf_damp->set_value(20000.0);
     amount->set_value(util::linear_to_db(0.366022));
     settings->reset("room-size");
     settings->reset("diffusion");
@@ -192,7 +204,7 @@ void ReverbUi::init_presets_buttons() {
   });
 
   preset_disco->signal_clicked().connect([=]() {
-    decay_time->set_value(1);
+    decay_time->set_value(1.0);
     hf_damp->set_value(3396.49);
     amount->set_value(util::linear_to_db(0.269807));
     settings->reset("room-size");
