@@ -1,4 +1,24 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "sink_input_effects_ui.hpp"
+#include "rnnoise_ui.hpp"
 
 SinkInputEffectsUi::SinkInputEffectsUi(BaseObjectType* cobject,
                                        const Glib::RefPtr<Gtk::Builder>& refBuilder,
@@ -28,6 +48,7 @@ SinkInputEffectsUi::SinkInputEffectsUi(BaseObjectType* cobject,
   auto b_crystalizer = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/crystalizer.glade");
   auto b_autogain = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/autogain.glade");
   auto b_delay = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/delay.glade");
+  auto b_rnnoise = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/rnnoise.glade");
 
   b_limiter->get_widget_derived("widgets_grid", limiter_ui, "com.github.wwmm.pulseeffects.limiter",
                                 "/com/github/wwmm/pulseeffects/sinkinputs/limiter/");
@@ -93,6 +114,9 @@ SinkInputEffectsUi::SinkInputEffectsUi(BaseObjectType* cobject,
   b_delay->get_widget_derived("widgets_grid", delay_ui, "com.github.wwmm.pulseeffects.delay",
                               "/com/github/wwmm/pulseeffects/sinkinputs/delay/");
 
+  b_rnnoise->get_widget_derived("widgets_grid", rnnoise_ui, "com.github.wwmm.pulseeffects.rnnoise",
+                                "/com/github/wwmm/pulseeffects/sinkinputs/rnnoise/");
+
   // add to stack
 
   stack->add(*limiter_ui, limiter_ui->name);
@@ -115,6 +139,7 @@ SinkInputEffectsUi::SinkInputEffectsUi(BaseObjectType* cobject,
   stack->add(*crystalizer_ui, crystalizer_ui->name);
   stack->add(*autogain_ui, autogain_ui->name);
   stack->add(*delay_ui, delay_ui->name);
+  stack->add(*rnnoise_ui, rnnoise_ui->name);
 
   // populate_listbox
 
@@ -138,6 +163,11 @@ SinkInputEffectsUi::SinkInputEffectsUi(BaseObjectType* cobject,
   add_to_listbox(crystalizer_ui);
   add_to_listbox(autogain_ui);
   add_to_listbox(delay_ui);
+  add_to_listbox(rnnoise_ui);
+
+  // show only speaker icon before "Application" label
+
+  app_output_icon->set_visible(true);
 
   level_meters_connections();
   up_down_connections();
@@ -161,7 +191,7 @@ auto SinkInputEffectsUi::add_to_stack(Gtk::Stack* stack, SinkInputEffects* sie_p
 
   auto settings = Gio::Settings::create("com.github.wwmm.pulseeffects.sinkinputs");
 
-  SinkInputEffectsUi* ui;
+  SinkInputEffectsUi* ui = nullptr;
 
   builder->get_widget_derived("widgets_box", ui, settings, sie_ptr);
 
@@ -172,11 +202,11 @@ auto SinkInputEffectsUi::add_to_stack(Gtk::Stack* stack, SinkInputEffects* sie_p
 }
 
 void SinkInputEffectsUi::on_app_added(std::shared_ptr<AppInfo> app_info) {
-  // Blacklist check
-  auto forbidden_app = BlacklistSettingsUi::app_is_blacklisted(app_info->name, PresetType::output);
+  // Blocklist check
+  auto forbidden_app = BlocklistSettingsUi::app_is_blocklisted(app_info->name, PresetType::output);
 
   if (forbidden_app) {
-    app_info->visible = BlacklistSettingsUi::get_blacklisted_apps_visibility();
+    app_info->visible = BlocklistSettingsUi::get_blocklisted_apps_visibility();
 
     if (!app_info->visible) {
       return;
@@ -408,6 +438,13 @@ void SinkInputEffectsUi::level_meters_connections() {
 
   connections.emplace_back(sie->delay_input_level.connect(sigc::mem_fun(*delay_ui, &DelayUi::on_new_input_level_db)));
   connections.emplace_back(sie->delay_output_level.connect(sigc::mem_fun(*delay_ui, &DelayUi::on_new_output_level_db)));
+
+  // rnnoise level meters connections
+
+  connections.emplace_back(
+      sie->rnnoise_input_level.connect(sigc::mem_fun(*rnnoise_ui, &RNNoiseUi::on_new_input_level_db)));
+  connections.emplace_back(
+      sie->rnnoise_output_level.connect(sigc::mem_fun(*rnnoise_ui, &RNNoiseUi::on_new_output_level_db)));
 }
 
 void SinkInputEffectsUi::up_down_connections() {
@@ -506,4 +543,7 @@ void SinkInputEffectsUi::up_down_connections() {
 
   connections.emplace_back(delay_ui->plugin_up->signal_clicked().connect([=]() { on_up(delay_ui); }));
   connections.emplace_back(delay_ui->plugin_down->signal_clicked().connect([=]() { on_down(delay_ui); }));
+
+  connections.emplace_back(rnnoise_ui->plugin_up->signal_clicked().connect([=]() { on_up(rnnoise_ui); }));
+  connections.emplace_back(rnnoise_ui->plugin_down->signal_clicked().connect([=]() { on_down(rnnoise_ui); }));
 }
