@@ -1,10 +1,29 @@
+/*
+ *  Copyright © 2017-2020 Wellington Wallace
+ *
+ *  This file is part of PulseEffects.
+ *
+ *  PulseEffects is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  PulseEffects is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with PulseEffects.  If not, see <https://www.gnu.org/licenses/>.
+ */
+
 #include "webrtc_ui.hpp"
 #include <cstring>
 
 namespace {
 
 auto echo_suppression_level_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "low") == 0) {
     g_value_set_int(value, 0);
@@ -19,21 +38,25 @@ auto echo_suppression_level_to_int(GValue* value, GVariant* variant, gpointer us
 
 auto int_to_echo_suppression_level(const GValue* value, const GVariantType* expected_type, gpointer user_data)
     -> GVariant* {
-  int v = g_value_get_int(value);
+  const auto v = g_value_get_int(value);
 
-  if (v == 0) {
-    return g_variant_new_string("low");
+  switch (v) {
+    case 0:
+      return g_variant_new_string("low");
+
+    case 1:
+      return g_variant_new_string("moderate");
+
+    case 2:
+      return g_variant_new_string("high");
+
+    default:
+      return g_variant_new_string("moderate");
   }
-
-  if (v == 1) {
-    return g_variant_new_string("moderate");
-  }
-
-  return g_variant_new_string("high");
 }
 
 auto noise_suppression_level_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "low") == 0) {
     g_value_set_int(value, 0);
@@ -50,25 +73,28 @@ auto noise_suppression_level_to_int(GValue* value, GVariant* variant, gpointer u
 
 auto int_to_noise_suppression_level(const GValue* value, const GVariantType* expected_type, gpointer user_data)
     -> GVariant* {
-  int v = g_value_get_int(value);
+  const auto v = g_value_get_int(value);
 
-  if (v == 0) {
-    return g_variant_new_string("low");
+  switch (v) {
+    case 0:
+      return g_variant_new_string("low");
+
+    case 1:
+      return g_variant_new_string("moderate");
+
+    case 2:
+      return g_variant_new_string("high");
+
+    case 3:
+      return g_variant_new_string("very-high");
+
+    default:
+      return g_variant_new_string("moderate");
   }
-
-  if (v == 1) {
-    return g_variant_new_string("moderate");
-  }
-
-  if (v == 2) {
-    return g_variant_new_string("high");
-  }
-
-  return g_variant_new_string("very-high");
 }
 
 auto gain_control_mode_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "adaptive-digital") == 0) {
     g_value_set_int(value, 0);
@@ -80,17 +106,22 @@ auto gain_control_mode_to_int(GValue* value, GVariant* variant, gpointer user_da
 }
 
 auto int_to_gain_control_mode(const GValue* value, const GVariantType* expected_type, gpointer user_data) -> GVariant* {
-  int v = g_value_get_int(value);
+  const auto v = g_value_get_int(value);
 
-  if (v == 0) {
-    return g_variant_new_string("adaptive-digital");
+  switch (v) {
+    case 0:
+      return g_variant_new_string("adaptive-digital");
+
+    case 1:
+      return g_variant_new_string("fixed-digital");
+
+    default:
+      return g_variant_new_string("adaptive-digital");
   }
-
-  return g_variant_new_string("fixed-digital");
 }
 
 auto voice_detection_likelihood_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "very-low") == 0) {
     g_value_set_int(value, 0);
@@ -107,21 +138,24 @@ auto voice_detection_likelihood_to_int(GValue* value, GVariant* variant, gpointe
 
 auto int_to_voice_detection_likelihood(const GValue* value, const GVariantType* expected_type, gpointer user_data)
     -> GVariant* {
-  int v = g_value_get_int(value);
+  const auto v = g_value_get_int(value);
 
-  if (v == 0) {
-    return g_variant_new_string("very-low");
+  switch (v) {
+    case 0:
+      return g_variant_new_string("very-low");
+
+    case 1:
+      return g_variant_new_string("low");
+
+    case 2:
+      return g_variant_new_string("moderate");
+
+    case 3:
+      return g_variant_new_string("high");
+
+    default:
+      return g_variant_new_string("low");
   }
-
-  if (v == 1) {
-    return g_variant_new_string("low");
-  }
-
-  if (v == 2) {
-    return g_variant_new_string("moderate");
-  }
-
-  return g_variant_new_string("high");
 }
 
 }  // namespace
@@ -196,42 +230,33 @@ WebrtcUi::~WebrtcUi() {
 }
 
 void WebrtcUi::reset() {
-  try {
-    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+  settings->reset("high-pass-filter");
 
-    update_default_key<bool>(settings, "high-pass-filter", section + ".webrtc.high-pass-filter");
+  settings->reset("echo-cancel");
 
-    update_default_key<bool>(settings, "echo-cancel", section + ".webrtc.echo-cancel");
+  settings->reset("echo-suppression-level");
 
-    update_default_string_key(settings, "echo-suppression-level", section + ".webrtc.echo-suppression-level");
+  settings->reset("noise-suppression");
 
-    update_default_key<bool>(settings, "noise-suppression", section + ".webrtc.noise-suppression");
+  settings->reset("noise-suppression-level");
 
-    update_default_string_key(settings, "noise-suppression-level", section + ".webrtc.noise-suppression-level");
+  settings->reset("gain-control");
 
-    update_default_key<bool>(settings, "gain-control", section + ".webrtc.gain-control");
+  settings->reset("extended-filter");
 
-    update_default_key<bool>(settings, "extended-filter", section + ".webrtc.extended-filter");
+  settings->reset("delay-agnostic");
 
-    update_default_key<bool>(settings, "delay-agnostic", section + ".webrtc.delay-agnostic");
+  settings->reset("target-level-dbfs");
 
-    update_default_key<int>(settings, "target-level-dbfs", section + ".webrtc.target-level-dbfs");
+  settings->reset("compression-gain-db");
 
-    update_default_key<int>(settings, "compression-gain-db", section + ".webrtc.compression-gain-db");
+  settings->reset("limiter");
 
-    update_default_key<bool>(settings, "limiter", section + ".webrtc.limiter");
+  settings->reset("gain-control-mode");
 
-    update_default_string_key(settings, "gain-control-mode", section + ".webrtc.gain-control-mode");
+  settings->reset("voice-detection");
 
-    update_default_key<bool>(settings, "voice-detection", section + ".webrtc.voice-detection");
+  settings->reset("voice-detection-frame-size-ms");
 
-    update_default_key<int>(settings, "voice-detection-frame-size-ms",
-                            section + ".webrtc.voice-detection-frame-size-ms");
-
-    update_default_string_key(settings, "voice-detection-likelihood", section + ".webrtc.voice-detection-likelihood");
-
-    util::debug(name + " plugin: successfully reset");
-  } catch (std::exception& e) {
-    util::debug(name + " plugin: an error occurred during reset process");
-  }
+  settings->reset("voice-detection-likelihood");
 }
